==> Excavar-1.20.1-3.1.5-sources.jar: de/melanx/excavar/impl/shape/Shapeless.java <==
package de.melanx.excavar.impl.shape;

import com.google.common.collect.Lists;
import de.melanx.excavar.api.shape.Matcher;
import de.melanx.excavar.api.shape.Shape;
import net.minecraft.core.BlockPos;
import net.minecraft.core.Direction;
import net.minecraft.world.level.Level;
import net.minecraft.world.level.block.state.BlockState;

import java.util.List;

public class Shapeless implements Shape {

    private static final List<BlockPos> CORNER_OFFSETS = Lists.newArrayList(
            new BlockPos(0, -1, -1),
            new BlockPos(0, -1, 1),
            new BlockPos(0, 1, -1),
            new BlockPos(0, 1, 1),
            new BlockPos(-1, 0, -1),
            new BlockPos(-1, 0, 1),
            new BlockPos(-1, -1, 0),
            new BlockPos(-1, -1, -1),
            new BlockPos(-1, -1, 1),
            new BlockPos(-1, 1, 0),
            new BlockPos(-1, 1, -1),
            new BlockPos(-1, 1, 1),
            new BlockPos(1, 0, -1),
            new BlockPos(1, 0, 1),
            new BlockPos(1, -1, 0),
            new BlockPos(1, -1, -1),
            new BlockPos(1, -1, 1),
            new BlockPos(1, 1, 0),
            new BlockPos(1, 1, -1),
            new BlockPos(1, 1, 1)
    );

    @Override
    public int addNeighbors(Level level, BlockPos pos, Direction side, BlockState originalState, List<BlockPos> blocksToMine, int stepsLeft) {
        //noinspection DuplicatedCode
        BlockPos.MutableBlockPos newPos = pos.m_122032_();
        for (Direction value : Direction.values()) {
            //noinspection DuplicatedCode
            if (stepsLeft > 0) {
                newPos.m_122173_(value);
                if (!blocksToMine.contains(newPos) && Matcher.SAME_BLOCK.test(originalState, level.m_8055_(newPos))) {
                    blocksToMine.add(newPos.m_7949_());
                    stepsLeft--;
                }
                newPos.m_122190_(pos);
            } else {
                return stepsLeft;
            }
        }
        newPos.m_122190_(pos);
        for (BlockPos offset : CORNER_OFFSETS) {
            //noinspection DuplicatedCode
            if (stepsLeft > 0) {
                newPos.m_122193_(offset);
                if (!blocksToMine.contains(newPos) && Matcher.SAME_BLOCK.test(originalState, level.m_8055_(newPos))) {
                    blocksToMine.add(newPos.m_7949_());
                    stepsLeft--;
                }
                newPos.m_122190_(pos);
            } else {
                return stepsLeft;
            }
        }

        return stepsLeft;
    }
}

==> Excavar-21.9.0-sources.jar: de/melanx/excavar/impl/shape/Shapeless.java <==
package de.melanx.excavar.impl.shape;

import com.google.common.collect.Lists;
import de.melanx.excavar.api.shape.Matcher;
import de.melanx.excavar.api.shape.Shape;
import net.minecraft.core.BlockPos;
import net.minecraft.core.Direction;
import net.minecraft.world.level.Level;
import net.minecraft.world.level.block.state.BlockState;

import java.util.List;

public class Shapeless implements Shape {

    private static final List<BlockPos> CORNER_OFFSETS = Lists.newArrayList(
            new BlockPos(0, -1, -1),
            new BlockPos(0, -1, 1),
            new BlockPos(0, 1, -1),
            new BlockPos(0, 1, 1),
            new BlockPos(-1, 0, -1),
            new BlockPos(-1, 0, 1),
            new BlockPos(-1, -1, 0),
            new BlockPos(-1, -1, -1),
            new BlockPos(-1, -1, 1),
            new BlockPos(-1, 1, 0),
            new BlockPos(-1, 1, -1),
            new BlockPos(-1, 1, 1),
            new BlockPos(1, 0, -1),
            new BlockPos(1, 0, 1),
            new BlockPos(1, -1, 0),
            new BlockPos(1, -1, -1),
            new BlockPos(1, -1, 1),
            new BlockPos(1, 1, 0),
            new BlockPos(1, 1, -1),
            new BlockPos(1, 1, 1)
    );

    @Override
    public int addNeighbors(Level level, BlockPos pos, Direction side, BlockState originalState, List<BlockPos> blocksToMine, int stepsLeft) {
        //noinspection DuplicatedCode
        BlockPos.MutableBlockPos newPos = pos.mutable();
        for (Direction value : Direction.values()) {
            //noinspection DuplicatedCode
            if (stepsLeft > 0) {
                newPos.move(value);
                if (!blocksToMine.contains(newPos) && Matcher.SAME_BLOCK.test(originalState, level.getBlockState(newPos))) {
                    blocksToMine.add(newPos.immutable());
                    stepsLeft--;
                }
                newPos.set(pos);
            } else {
                return stepsLeft;
            }
        }
        newPos.set(pos);
        for (BlockPos offset : CORNER_OFFSETS) {
            //noinspection DuplicatedCode
            if (stepsLeft > 0) {
                newPos.move(offset);
                if (!blocksToMine.contains(newPos) && Matcher.SAME_BLOCK.test(originalState, level.getBlockState(newPos))) {
                    blocksToMine.add(newPos.immutable());
                    stepsLeft--;
                }
                newPos.set(pos);
            } else {
                return stepsLeft;
            }
        }

        return stepsLeft;
    }
}
